==> hboard-1.0-rc2.tar.gz: hboard/rename_icon.php <==
<?php

/* EtchiBoard Version 1.0
     iconman.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("skin/$admin_data[skin]/style.php"); // Ų
include ("lib/message.inc"); // ޽ function

if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 // α ° ƴ϶
 PrintMessage("<br> Ű ã  ϴ.", "error");
}

else {
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
<title>EtchiBoard  </title>
</head>

<body onload="document.rename_icon.rename_to.focus();">
<p align="center">&nbsp;</p>
<table align="center" border="1" cellspacing="0" width="406" bordercolordark="white" bordercolorlight="black">
    <tr>
        <td width="348" bgcolor="#EAEAEA" height="13">
            <p><span style="font-size:9pt;"><b><font color="#676767">&nbsp; 
            ̸ ٲٱ</font></b></span></p>
        </td>
        <td width="48" bgcolor="#EAEAEA" height="13">
            <p align="center"><span style="font-size:9pt;"><a href="javascript:window.close()"><font color="black">â ݱ</font></a></span></p>
        </td>
    </tr>
    <tr>
        <td width="400" height="187" colspan="2">
            <form name="rename_icon" method="post" action="rename_icon_ok.php">
                <p align="center">
				<br><span style="font-size:10pt;">
				<img src="<?="db/ico/" .$file?>" width="100" height="100" border="1" alt="<?=$file?>"><br>
				</span>
				<span style="font-size:5pt;"><br>
				<span style="font-size:10pt;"><?=$file?>&nbsp; <font color="#003399"≯ </font>մϴ.<br>
				<br>
				</span>
				
				<span style="font-size:9pt;">
				<b>Rename to:</b>
				<input type="hidden" name="file" value="<?=$file?>">
				<input type="text" name="rename_to" value="<?=$file?>" maxlength=100>&nbsp;
				<input type="submit" name="sendform" value="ٲٱ"> 
                <input type="button" name="cancel" value="" onclick="history.back(1);">
				&nbsp;</span>
				</span><br><br>
				<span style="font-size:8pt;"><font color="gray">:  ̸ ϰ Ǹ,  ش <br>ߴ ǰ߱   ̸ Բ ˴ϴ.</font>
				</span>
			</form>
		</td>
    </tr>
</table>
</body>
</html>

<?php
}
?>

==> hboard-1.0.4.tar.gz: hboard/rename_icon.php <==
<?php



/* EtchiBoard Version 1.0

     iconman.php

     http://etchibbs.kldp.net */



/***************************************************************************

 *

 *   This program is free software; you can redistribute it and/or modify

 *   it under the terms of the GNU General Public License as published by

 *   the Free Software Foundation; either version 2 of the License, or

 *   (at your option) any later version.

 *

 ***************************************************************************/



include ("lib/admin.inc"); //  ȯ漳

include ("skin/$admin_data[skin]/style.php"); // Ų

include ("lib/message.inc"); // ޽ function



if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {

 // α ° ƴ϶

 PrintMessage("<br> Ű ã  ϴ.", "error");

}



else {

?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<html>

<head>

<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">

<title>EtchiBoard  </title>

</head>



<body onload="document.rename_icon.rename_to.focus();">

<p align="center">&nbsp;</p>

<table align="center" border="1" cellspacing="0" width="406" bordercolordark="white" bordercolorlight="black">

    <tr>

        <td width="348" bgcolor="#EAEAEA" height="13">

            <p><span style="font-size:9pt;"><b><font color="#676767">&nbsp; 

            ̸ ٲٱ</font></b></span></p>

        </td>

        <td width="48" bgcolor="#EAEAEA" height="13">

            <p align="center"><span style="font-size:9pt;"><a href="javascript:window.close()"><font color="black">â ݱ</font></a></span></p>

        </td>

    </tr>

    <tr>

        <td width="400" height="187" colspan="2">

            <form name="rename_icon" method="post" action="rename_icon_ok.php">

                <p align="center">

				<br><span style="font-size:10pt;">

				<img src="<?php echo "db/ico/" .$file?>" width="100" height="100" border="1" alt="<?php echo $file?>"><br>

				</span>

				<span style="font-size:5pt;"><br>

				<span style="font-size:10pt;"><?php echo $file?>&nbsp; <font color="#003399"≯ </font>մϴ.<br>

				<br>

				</span>

				

				<span style="font-size:9pt;">

				<b>Rename to:</b>

				<input type="hidden" name="file" value="<?php echo $file?>">

				<input type="text" name="rename_to" value="<?php echo $file?>" maxlength=100>&nbsp;

				<input type="submit" name="sendform" value="ٲٱ"> 

                <input type="button" name="cancel" value="" onclick="history.back(1);">

				&nbsp;</span>

				</span><br><br>

				<span style="font-size:8pt;"><font color="gray">:  ̸ ϰ Ǹ,  ش <br>ߴ ǰ߱   ̸ Բ ˴ϴ.</font>

				</span>

			</form>

		</td>

    </tr>

</table>

</body>

</html>



<?php

}

?>
